@@ -1,3 +1,4 @@
+from . import interval
 from ._reader import Item, ParsingError, Reader, read_gff
 from ._version import __version__
 
@@ -6,5 +7,6 @@ __all__ = [
     "ParsingError",
     "Reader",
     "__version__",
+    "interval",
     "read_gff",
 ]
